==> defi_state_querier-0.0.3-py3-none-any.whl: defi_services/services/lending/lending_info/fantom/geist_ftm.py <==
GEIST_ETH = {
    "address": "0x9fad24f572045c7869117160a571b2e50b10d068",
    "name": "Geist Lending Pool",
    "rewardToken": "0xd8321aa83fb0a4ecd6348d4577431310a6e0814d",
    "multiFeeAddress": "0x49c93a95dbcc9a6a4d8f77e59c038ce5020e82f8",
    "chefIncentiveAddress": '0x297fddc5c33ef988dd03bd13e162ae084ea1fe57',
    "oracleAddress": "0xc466e3fee82c6bdc2e17f2eaf2c6f1e91ad10fd3",
    "poolToken": "0xd8321aa83fb0a4ecd6348d4577431310a6e0814d",
    "forked": "aave-v2",
    "type": "LENDING_POOL",
    "reservesList": {
        "0x8d11ec38a3eb5e956b052f67da8bdc9bef8abf3e": {
            "tToken": "0x07e6332dd090d287d3489245038daf987955dcfb",
            "dToken": "0xd25aa085ef6a304c6861750f16a3fa0d03d25ddb",
            "sdToken": "0x069d292b2b7d7e588b09fa8329ea27545395d690",
            "liquidationThreshold": 0.8
        },
        "0x74b23882a30290451a17c44f4f05243b6b58c76d": {
            "tToken": "0x25c130b2624cf12a4ea30143ef50c5d68cefa22f",
            "dToken": "0xbdce00a99a4b7e99f7a6af7d44724f77d471f923",
            "sdToken": "0xcec0c5b239e42d59ce3f8fbb54d7d30640fb4dee",
            "liquidationThreshold": 0.825
        },
        "0x21be370d5312f44cb42ce377bc9b8a0cef1a4c83": {
            "tToken": "0x39b3bd37208cbade74d0fcbdbb12d606295b430a",
            "dToken": "0x53d01d351fa001db3c893388e43e3c630a8764f5",
            "sdToken": "0xfe008b75b580c0c0daf0b59f6b600f035cc79c33",
            "liquidationThreshold": 0.65
        },
        "0x321162cd933e2be498cd2267a90534a804051b11": {
            "tToken": "0x38aca5484b8603373acc6961ecd57a6a594510a3",
            "dToken": "0x4318d7ad332a0fee9db6d2b9b4b021fda865abdb",
            "sdToken": "0x44088023b1fd7f12d317cd7b192049019a4f61d9",
            "liquidationThreshold": 0.75
        },
        "0x049d68029688eabf473097a2fc38ef61633a3c7a": {
            "tToken": "0x940f41f0ec9ba1a34cf001cc03347ac092f5f6b5",
            "dToken": "0x816ed5ee0c7b011024be3fb5b6166f59a7cbe0e4",
            "sdToken": "0xe22367ed4ec6fd250f712d61560bb46ce5b29a82",
            "liquidationThreshold": 0.85
        },
        "0x04068da6c83afcfa0e13ba15a6696662335d5b75": {
            "tToken": "0xe578c856933d8e1082740bf7661e379aa2a30b26",
            "dToken": "0x3eef981640064d63bb7ead4c6e3c0457e5c2934d",
            "sdToken": "0x66ab97bcce5176dd81601be0e806cde8370896f7",
            "liquidationThreshold": 0.85
        },
        "0x1e4f97b9f9f913c46f1632781732927b9019c68b": {
            "tToken": "0x690754a168b022331caa2467207c61919b3f8a98",
            "dToken": "0x811a951d15f4dd33e9aa8d6f7aff6d1433fe644a",
            "sdToken": "0xdfec74cb2433527fba605562cf3d2ffa71d2ef0c",
            "liquidationThreshold": 0.65
        },
        "0x82f0b8b456c1a451378467398982d4834b6829c1": {
            "tToken": "0xc664fc7b8487a3e10824cda768c1d239f2403bbe",
            "dToken": "0xe6f5b2d4de014d8fa4c45b744921ffdf13f15d4a",
            "sdToken": "0x30522d0ea6be3938cbedf9a9020fa13c439ee71e",
            "liquidationThreshold": 0.8
        },
        "0xb3654dc3d10ea7645f8319668e8f54d2574fbdc8": {
            "tToken": "0xbecf29265b0cc8d33fa24446599955c7bcf7f73b",
            "dToken": "0xfc8f690b285a013a86b7a71c0af70bc57302e7e4",
            "sdToken": "0x54d547ed8e6f6b237b3c5ee50680bb08b35708b7",
            "liquidationThreshold": 0.65
        }
    }
}

==> defi_state_querier-0.4.22-py3-none-any.whl: defi_services/services/lending/lending_info/fantom/geist_ftm.py <==
GEIST_ETH = {
    "address": "0x9fad24f572045c7869117160a571b2e50b10d068",
    "name": "Geist Lending Pool",
    "rewardToken": "0xd8321aa83fb0a4ecd6348d4577431310a6e0814d",
    "multiFeeAddress": "0x49c93a95dbcc9a6a4d8f77e59c038ce5020e82f8",
    "stakedIncentiveAddress": '0x297fddc5c33ef988dd03bd13e162ae084ea1fe57',
    "oracleAddress": "0xc466e3fee82c6bdc2e17f2eaf2c6f1e91ad10fd3",
    "poolToken": "0xd8321aa83fb0a4ecd6348d4577431310a6e0814d",
    "forked": "aave-v2",
    "type": "LENDING_POOL",
    "reservesList": {
        "0x8d11ec38a3eb5e956b052f67da8bdc9bef8abf3e": {
            "tToken": "0x07e6332dd090d287d3489245038daf987955dcfb",
            "dToken": "0xd25aa085ef6a304c6861750f16a3fa0d03d25ddb",
            "sdToken": "0x069d292b2b7d7e588b09fa8329ea27545395d690",
            "liquidationThreshold": 0.8
        },
        "0x74b23882a30290451a17c44f4f05243b6b58c76d": {
            "tToken": "0x25c130b2624cf12a4ea30143ef50c5d68cefa22f",
            "dToken": "0xbdce00a99a4b7e99f7a6af7d44724f77d471f923",
            "sdToken": "0xcec0c5b239e42d59ce3f8fbb54d7d30640fb4dee",
            "liquidationThreshold": 0.825
        },
        "0x21be370d5312f44cb42ce377bc9b8a0cef1a4c83": {
            "tToken": "0x39b3bd37208cbade74d0fcbdbb12d606295b430a",
            "dToken": "0x53d01d351fa001db3c893388e43e3c630a8764f5",
            "sdToken": "0xfe008b75b580c0c0daf0b59f6b600f035cc79c33",
            "liquidationThreshold": 0.65
        },
        "0x321162cd933e2be498cd2267a90534a804051b11": {
            "tToken": "0x38aca5484b8603373acc6961ecd57a6a594510a3",
            "dToken": "0x4318d7ad332a0fee9db6d2b9b4b021fda865abdb",
            "sdToken": "0x44088023b1fd7f12d317cd7b192049019a4f61d9",
            "liquidationThreshold": 0.75
        },
        "0x049d68029688eabf473097a2fc38ef61633a3c7a": {
            "tToken": "0x940f41f0ec9ba1a34cf001cc03347ac092f5f6b5",
            "dToken": "0x816ed5ee0c7b011024be3fb5b6166f59a7cbe0e4",
            "sdToken": "0xe22367ed4ec6fd250f712d61560bb46ce5b29a82",
            "liquidationThreshold": 0.85
        },
        "0x04068da6c83afcfa0e13ba15a6696662335d5b75": {
            "tToken": "0xe578c856933d8e1082740bf7661e379aa2a30b26",
            "dToken": "0x3eef981640064d63bb7ead4c6e3c0457e5c2934d",
            "sdToken": "0x66ab97bcce5176dd81601be0e806cde8370896f7",
            "liquidationThreshold": 0.85
        },
        "0x1e4f97b9f9f913c46f1632781732927b9019c68b": {
            "tToken": "0x690754a168b022331caa2467207c61919b3f8a98",
            "dToken": "0x811a951d15f4dd33e9aa8d6f7aff6d1433fe644a",
            "sdToken": "0xdfec74cb2433527fba605562cf3d2ffa71d2ef0c",
            "liquidationThreshold": 0.65
        },
        "0x82f0b8b456c1a451378467398982d4834b6829c1": {
            "tToken": "0xc664fc7b8487a3e10824cda768c1d239f2403bbe",
            "dToken": "0xe6f5b2d4de014d8fa4c45b744921ffdf13f15d4a",
            "sdToken": "0x30522d0ea6be3938cbedf9a9020fa13c439ee71e",
            "liquidationThreshold": 0.8
        },
        "0xb3654dc3d10ea7645f8319668e8f54d2574fbdc8": {
            "tToken": "0xbecf29265b0cc8d33fa24446599955c7bcf7f73b",
            "dToken": "0xfc8f690b285a013a86b7a71c0af70bc57302e7e4",
            "sdToken": "0x54d547ed8e6f6b237b3c5ee50680bb08b35708b7",
            "liquidationThreshold": 0.65
        }
    }
}
